S class
Constructors
- S()
Properties
- cancel → String
-
Cancelno setter - choose_photo → String
-
Choose photono setter - hashCode → int
-
The hash code for this object.
no setterinherited
- network_error_tip → String
-
The current network is unavailable, please check your network settings.no setter - permission_request_tip → String
-
Please add permissions on the settings pageno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sure → String
-
OKno setter - take_photo → String
-
Take photono setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Locale locale) → Future< S> -
maybeOf(
BuildContext context) → S? -
of(
BuildContext context) → S
Constants
- delegate → const AppLocalizationDelegate